# Introduction

This repository contains related code for the RSS 2021 [paper](http://www.roboticsproceedings.org/rss17/p053.pdf) "Move Beyond Trajectories: Distribution Space Coupling for Crowd Navigation" by Muchen Sun, Francesca Baldini, Pete Trautman and Todd Murphey.

## Tutorials

We provide a Jupyter notebook tutorials for our algorithm. You can find them under the "notebooks" directory.
 - [Tutorial 1: distribution space coupling in one-dimensional space](./notebooks/distnav_1d_tutorial.ipynb): In the first tutorial, we will build from scratch on a one-dimensional two-agents toy example to show how DistNav optimization works. We will show both the analytical solution with numerical integration and approximated solution with sampling and Monte-Carlo integration, and how they can match with
   each other. You can find a copy of the notebook in Google Colaboratory [**here**](https://colab.research.google.com/github/MurpheyLab/DistNav/blob/master/notebooks/distnav_1d_tutorial.ipynb).
